/*
 * Copyright © 2021-2023 Fachhochschule für die Wirtschaft (FHDW) Hannover
 *
 * This file is part of ipspiel24-GD.
 *
 * ipspiel24-GD is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * ipspiel24-GD is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with ipspiel24-GD. If not, see
 * <http://www.gnu.org/licenses/>.
 */
package de.fhdw.gaming.GefangenenDilemma.strategy;

import java.util.Optional;

import de.fhdw.gaming.GefangenenDilemma.domain.GDPlayer;
import de.fhdw.gaming.GefangenenDilemma.domain.GDState;
import de.fhdw.gaming.GefangenenDilemma.domain.GDStrategy;
import de.fhdw.gaming.GefangenenDilemma.moves.GDMove;
import de.fhdw.gaming.GefangenenDilemma.moves.factory.GDMoveFactory;

/**
 * Implements {@link GDStrategy} by always saying "no".
 */
public final class GDSnitchStrategy implements GDStrategy {

    /**
     * The factory for creating Gefangenen-Dilemma moves.
     */
    private final GDMoveFactory moveFactory;

    /**
     * Creates an {@link GDSnitchStrategy}.
     *
     * @param moveFactory The factory for creating Gefangenen-Dilemma moves.
     */
    GDSnitchStrategy(final GDMoveFactory moveFactory) {
        this.moveFactory = moveFactory;
    }

    @Override
    public Optional<GDMove> computeNextMove(
            final int gameId,
            final GDPlayer player,
            final GDState state,
            final long maxComputationTimePerMove) {
        return Optional.of(this.moveFactory.createSnitchMove());
    }

    @Override
    public String toString() {
        return GDSnitchStrategy.class.getSimpleName();
    }
}
